@@ -5,7 +5,7 @@ import argparse
 import logging
 from datetime import datetime, timedelta
 
-__version_info__ = ('0', '0', '4')
+__version_info__ = ('0', '0', '6')
 __version__ = '.'.join(__version_info__)
 
 # from VideoTrackingWindowWindow import Ui_VideoTrackingWindowWindow
@@ -465,7 +465,7 @@ class Tracker(QWidget):
         self.addBox(new_box)
 
 
-if __name__ == '__main__':
+def main():
     app = QApplication(sys.argv)
 
     parser = argparse.ArgumentParser(
@@ -515,3 +515,7 @@ if __name__ == '__main__':
         player.openVideo(filename=args.videopath)
 
     sys.exit(app.exec_())
+
+
+if __name__ == '__main__':
+    main()
\ No newline at end of file
